@@ -68,6 +68,12 @@ Rcpp.package.skeleton <- function(
 		message( " >> added Makevars file with Rcpp settings" )
 	}
 	
+	Makevars.win <- file.path( src, "Makevars.win" )
+	if( !file.exists( Makevars.win ) ){
+		file.copy( file.path( skeleton, "Makevars.win" ), Makevars.win )
+		message( " >> added Makevars.win file with Rcpp settings" )
+	}
+	
 	header <- readLines( file.path( skeleton, "rcpp_hello_world.h" ) )
 	header <- gsub( "@PKG@", name, header, fixed = TRUE )
 	writeLines( header , file.path( src, "rcpp_hello_world.h" ) )
