@@ -28,11 +28,22 @@
 #include <Rcpp/Symbol.h>
 #include <Rcpp/Language.h>
 
+#include <Rcpp/RObject.h>
+
 namespace Rcpp{ 
 
 class Environment: public RObject{
 public:
 
+	class not_found : public std::exception{
+	public:
+		not_found( const std::string& binding ) ;
+		virtual ~not_found() throw() ;
+		virtual const char* what() const throw();
+	private:
+		std::string binding ;
+	}        ;
+	
    /**
      * Exception thrown when attempting to perform an operation on 
      * a binding and there is no such binding
@@ -316,6 +327,15 @@ public:
      */
     SEXP get(const std::string& name) const ;
     
+    /**
+     * Get an object from the environment or one of its
+     * parents
+     *
+     * @param name name of the object
+     *
+     */
+    SEXP find( const std::string& name) const ;
+    
     /**
      * Indicates if an object called name exists in the 
      * environment
